==> cmsmadesimple-1.6.6.tgz: cms/modules/TinyMCE/lang/ext/ro_RO.php <==
<?php
$lang['friendlyname'] = 'Editorul TinyMCE WYSIWYG';
$lang['uninstalled'] = 'Modul dezinstalat.';
$lang['installed'] = 'Modul versiunea %s instalat.';
$lang['stripbackgroundtags'] = 'Scoatere taguri background din CSS';
$lang['stiptags_help'] = 'Aceasta optiune incearca sa inlature setarile pentru background din stylesheet.';
$lang['source_formatting_text'] = 'Aplicare formatare sursa la HTML output';
$lang['dropdownblockformats_text'] = 'Formate bloc in meniu dropdown';
$lang['allowtables'] = 'Se permit operatiuni tabele';
$lang['newlinestyle_text'] = 'Stil linie noua';
$lang['pstyle'] = 'stil - <p>';
$lang['brstyle'] = 'stil - <br/>';
$lang['usecompressiontext'] = 'Folosire compresie gz';
$lang['usecompressionhelp'] = 'Aceasta setare poate grabi incarcarea TinyMCE, dar poate si si faca sa nu se mai incarce pe unele sisteme. Folositi cu precautie.';
$lang['forcedrootblocktext'] = 'Fortare bloc radacina <p>';
$lang['forcedrootblockhelp'] = 'Forteaza ca, continutul returnat sa fie incadrat cel putin intr-un tag <p>';
$lang['filepickerstyle'] = 'Stil selector fisiere';
$lang['filepickersize'] = 'Dimensiune selector fisiere';
$lang['allowuploadtext'] = 'Se permite uploadul si crearea de foldere in selectorul de fisiere';
$lang['allowscalingtext'] = 'Se permite redimnesionarea on-the-fly a imaginilor uploadate';
$lang['scalingdimensionstext'] = 'Dimensiuni implicite';
$lang['resizeto'] = 'Redimensionare la:';
$lang['useadvancedprofile'] = 'Folosire profil avansat TinyMCE';
$lang['saveprofile'] = 'Salvare profil';
$lang['profilesaved'] = 'Profilul a fost salvat';
$lang['profiles_tab'] = 'Profile';
$lang['advanced_backend_toolbars'] = 'Setari avansate profile backend';
$lang['savestyles'] = 'Salvare stiluri';
$lang['allowadvancedprofile'] = 'Se permite folosirea profilulului avansat in TinyMCE';
$lang['showfilemanagement'] = 'Afisare optiuni management fisiere';
$lang['showfilemanagementhelp'] = 'Se afiseaza optiunile de mannagement fisiere cum ar fi upload, creare folder si stergere fisiere in Selector Fisiere, daca utilizatorul are permisiunile necesare pentru aceste operatiuni.';
$lang['deleteconfirmation'] = 'Sunteti sigur ca acest fisier trebuie sters?';
$lang['deletefilesuccess'] = 'a fost sters cu succes';
$lang['deletefilefila'] = 'nu a putut fi sters';
$lang['cannotreadconfig'] = 'Nu s-a putut citi fisierul tinyconfig.php direct asa ca TinyMCE probabil nu va functiona. Ar trebui sa verificati permisiunile pentru fisier si pentru folderele parinte, care ar trebui sa fie de citire pentru toti si cu permisiuni de scriere pentru proprietar.';
$lang['filenameonly'] = 'Afisare nume fisiere';
$lang['thumbnailsonly'] = 'Afisare miniaturi';
$lang['showthumbnailfilestext'] = 'Afisare fisiere miniaturi in liste';
$lang['filenameandthumbnails'] = 'Afisare si nume fisiere si miniaturi';
$lang['skinstext'] = 'Tema';
$lang['skinvariationtext'] = 'Variatie tema';
$lang['advancedwarning'] = '<strong>Luati nota!<br/>Daca schimbati aceste setari puteti face ca TinyMCE sa nu mai mearga sau codul generat sa fie gresit. Editati numai daca stiti ce faceti! Consultati site-ul TinyMCE inainte de a va juca cu aceste setari.</strong>';
$lang['entityencoding_text'] = 'Encodare entitati';
$lang['rawencoding'] = 'Encodare raw (cea mai rapida, functioneaza in cele mai multe cazuri)';
$lang['namedencoding'] = 'Encodare nume (gen &nbsp;)';
$lang['numericencoding'] = 'Encodare numerica (gen &amp;#160;)';
$lang['show_path_text'] = 'Afisare cale element in josul editorului';
$lang['toolbar_tab'] = 'Bara de unelte';
$lang['toolbar_help'] = 'Aceste optiuni ar trebui sa contina o lista de butoane / nume de controale separate prin virgula care se vor insera in bara de unelte. Caracterul | poate fi folosit in loc de cuvantul &#039;separator&#039;';
$lang['toolbar_text'] = 'Bara de unelte';
$lang['toolbarhelptext'] = 'Clic aici pentru a vedea instructiuni referitoare la bara de unelte in TinyMCE-wiki.';
$lang['editor_width_text'] = 'Latime camp editor';
$lang['editor_height_text'] = 'Inaltime camp editor';
$lang['auto'] = 'Auto ';
$lang['or'] = 'sau';
$lang['datetimeformat_text'] = 'Format data/timp';
$lang['timetext'] = 'Timp';
$lang['datetext'] = 'Data';
$lang['datetimeformat_help'] = 'Clic aici pentru a primi ajutor despre cum se formateaza data/timpul';
$lang['extraconfigtext'] = 'Extra configurare';
$lang['extraconfighelp'] = 'O singura declaratie per linie, fara virgule, va rugam. Verificati TinyMCE-wiki pentru instructiuni.';
$lang['customdropdowntext'] = 'Dropdown custom';
$lang['customdropdownhelp'] = 'Insereaza bucati customizabile de cod/text prin selectia lor dintr-un meniu dropdown. 
Utilizari evidente sunt pentru accces facil la taguri etc. Meniul este inserat in bara de unlete folosind &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Startup activat';
$lang['startenabledhelp'] = 'Debifand aceasta casuta se pornesc editoarele Tiny intr-o stare dezactivata. Ar trebui sa fie folosita impreuna cu butonul de stare.';
$lang['loadcmslinkertext'] = 'Incarcare CMS-linker';
$lang['loadcmslinkerhelp'] = 'Aceasta setare genereaza codul javascript de care este nevoie pentru a permite &#039;cmslinker&#039; sa fie adaugat la bara de unelte.';
$lang['cmslinkerstyletext'] = 'Stil link CMS-linker';
$lang['cmsselflinkstyle'] = 'Stil {cms_selflink}';
$lang['ahrefstyle'] = 'stil-<a href>';
$lang['relativeurlstext'] = 'Generare url-uri relative';
$lang['forcecleanpastetext'] = 'Fortare curatare la lipire (paste)';
$lang['forcecleanpastehelp'] = 'Aceasta setare ar trebui sa fie activate pentru a inlatura codurile ciudate de formatare cand se lipeste din Word etc.';
$lang['bodycss_text'] = 'CSS tag body';
$lang['bodycss_help'] = 'Va fi adaugat la definitia css a elementului body. Hint: Culoarea de fundal poate fi setata folosind &quot;background-color: white&quot;';
$lang['includeonlyscreencss_text'] = 'Include numai CSS screen';
$lang['includeonlyscreencss_help'] = 'Daca se selecteaza aceasta optiune numai stylesheet-urile atasate cu mediatype: screen vor fi incluse in stilurile pe care TinyMCE le gestioneaza.';
$lang['usestaticconfigtext'] = 'Folosire fisier configurare static';
$lang['usestaticconfighelp'] = 'Aceasta setare poate ajuta sa mearga TinyMCE pe sistemele unde hostingul adauga statistici etc. la orice output, stricand fisierul de configurare javascript creat dinamic';
$lang['usestaticconfigwarning'] = 'Atentie! Aveti optiunea de fisier de configurare static activata dar folderul /tmp/ nu are permisiuni de scriere. Acest lucru va impiedica modulul sa salveze fisierul static de configurare si sunt sanse foarte mari ca TinyMCE sa NU fie operational.';
$lang['showtogglebutton_text'] = 'Afisare checkbox pentru pornire/oprire wysiwyg';
$lang['togglewysiwyg'] = 'Pornire/oprire WYSIWYG';
$lang['styles_tab'] = 'Stiluri CSS';
$lang['styles_help'] = ' Daca lasati campul gol, TinyMCE va parsa stilesheet-urile CSS si va lista clasele de stiluri pe care le contin. 
  Daca doriti ca numai unele stiluri sa fie afisate utilizatorului, specificati-le in forma &quot;CustomName1=style1; CustomName2=style2&quot;, 
  &quot;style1&quot; fiind o clasa din stylesheet si nu puneti . (punctul) folosit in mod normal pentru selectorii de clase pentru exista deja in CSS, va arata asa <span class=&quot;style1&quot;>text</span>, in primul camp de mai jos. 
';
$lang['css_styles_text'] = 'Stiluri';
$lang['accessdenied'] = 'Acces Interzis. Verificati permisiunile.';
$lang['error'] = 'Eroare!';
$lang['submit'] = 'Trimitere';
$lang['update'] = 'Actualizare';
$lang['savesettings'] = 'Salvare setari';
$lang['settings'] = 'Setari';
$lang['settingssaved'] = 'Setarile au fost salvate';
$lang['saveadvanced'] = 'Salvare setari avansate';
$lang['advancedsaved'] = 'Setarile avansate au fost salvate';
$lang['toolbarsaved'] = 'Bara de unelte a fost salvata';
$lang['stylessaved'] = 'Stilurile au fost salvate';
$lang['testareatext'] = '<p>Arie de test, nici un fel de continut nu va fi stricat daca va jucati aici...</p>';
$lang['reset'] = 'Resetare la setarile implicite';
$lang['resetall'] = 'Resetati toate setarile la valorile implicite';
$lang['confirmreset'] = 'Sunteti sigur ca doriti sa resetati aceste setari la valorile lor implicite?';
$lang['confirmresetall'] = 'Sunteti sigur ca doriti sa resetati TOATE setarile la valorile implicite?';
$lang['settingsreset'] = 'Aceste setari au fost resetate la valorile implicite';
$lang['allsettingsreset'] = 'Toate setarile au fost resetate la valorile implicite';
$lang['upgraded'] = 'a fost actualizat la versiunea %s';
$lang['customdropdown'] = 'Meniu dropdown custom';
$lang['cmsmslinker'] = 'Inserare link catre pagina cmsms';
$lang['backend_toolbars'] = 'Setari profil arie administrare';
$lang['frontend_toolbars'] = 'Setarri profil frontend';
$lang['plugins_tab'] = 'Plugin-uri';
$lang['plugins_help'] = 'Alegeti plugin-urile pe care doriti sa le activati. Documentatia poate fi gasita <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">aici</a>';
$lang['plugins_text'] = 'Plugin-uri';
$lang['saveplugins'] = 'Salvare plugin-uri';
$lang['pluginssaved'] = 'Plugin-urile au fost salvate';
$lang['youareintext'] = 'Sunteti la';
$lang['loadstylesheettext'] = 'Incarcare stylesheet pentru continut (recomandat)';
$lang['extrastylestext'] = 'Adaugiri la stylesheet';
$lang['extrastyleshelp'] = 'CSS-ul introdus aici va fi adaugat la stylesheet-ul citit de TinyMCE dupa ce primeste stilurile CMSms';
$lang['uploadnewfile'] = 'Fisier nou';
$lang['uploadfile'] = 'Upload ';
$lang['createnewdir'] = 'Folder nou';
$lang['createdir'] = 'Creare';
$lang['nodirname'] = 'Nu a fost dat un nume de folder';
$lang['direxists'] = 'Numele de folder exista deja';
$lang['newdircreated'] = 'Folderul nou a fost creat';
$lang['newdirfailed'] = 'O eroare a aparut la creare folder';
$lang['nofile'] = 'Nici un fisier nu a fost uploadat';
$lang['filetoobig'] = 'Fisierul uploadat este prea mare';
$lang['uploadfailed'] = 'Eroare la mutare fisier uploadat la locul lui';
$lang['fileuploaded'] = 'Fisier uploadat cu succes';
$lang['filepickertitle'] = 'Selectie fisier CMSMadeSimple';
$lang['success'] = 'Succes';
$lang['fileoperations'] = 'Operatiuni fisiere';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Dimensiune';
$lang['dimensions'] = 'LxH ';
$lang['advanced_tab'] = 'Avansat';
$lang['help'] = '	<h3>Ce face acesta?</h3>
	<p>Permite folosirea TinyMCE ca editor WYSIWYG.</p>
	<h3>Cum se foloseste?</h3>
	<p>Instalati-l, apoi mergeti la Preferinte utilizator si setati TinyMCE ca editor wysiwyg preferat.</p>
	<h3>Probleme</h3>
	unii utilizatori au probleme cu Tiny la modu ca nu se afiseaza dupa instalare sau actualizare. Aici este un checklist de lucruri pe care le puteti incerca inainte de a cere ajutor mai departe.
	<br/>
	<ul>
	<li>1. Va rugam, VA RUGAM, incercati sa re-uploadati folderul modules/TinyMCE pe server. Ati fi uimiti sa aflati de cate ori acest lucru a salvat situatia.</li>
	<li>2. Incercati sa activati optiunea de fisier configurare static. Notati ca acest lucru cere ca folderul /tmp/ sa aiba permisiuni de scriere pentru webserver</li>
	<li>3. Daca actualizati, incercati sa resetati toate setarile. Nu e frumos daca ati facut o multime de modificari, stim, dar o multime de lucruri se pot schimba de la versiune la versiune.</li>
	</ul>
	<br/>
		
';
$lang['utmc'] = '156861353';
$lang['utma'] = '156861353.3573843717708992500.1250056267.1250579160.1250588117.15';
$lang['utmz'] = '156861353.1250579160.14.3.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/project/files/6|utmcmd=referral';
$lang['qcb'] = '1912438266';
$lang['qca'] = '1249980835-92593492-79567608';
?>

==> cmsmadesimple-1.8.2p0.tgz: cms/modules/TinyMCE/lang/ext/ro_RO.php <==
<?php
$lang['friendlyname'] = 'Editorul TinyMCE WYSIWYG';
$lang['uninstalled'] = 'Modul dezinstalat.';
$lang['installed'] = 'Modul versiunea %s instalat.';
$lang['stripbackgroundtags'] = 'Scoatere taguri background din CSS';
$lang['stiptags_help'] = 'Aceasta optiune incearca sa inlature setarile pentru background din stylesheet.';
$lang['source_formatting_text'] = 'Aplicare formatare sursa la HTML output';
$lang['dropdownblockformats_text'] = 'Formate bloc in meniu dropdown';
$lang['allowtables'] = 'Se permit operatiuni tabele';
$lang['newlinestyle_text'] = 'Stil linie noua';
$lang['pstyle'] = 'stil - <p>';
$lang['brstyle'] = 'stil - <br/>';
$lang['usecompressiontext'] = 'Folosire compresie gz';
$lang['usecompressionhelp'] = 'Aceasta setare poate grabi incarcarea TinyMCE, dar poate si si faca sa nu se mai incarce pe unele sisteme. Folositi cu precautie.';
$lang['forcedrootblocktext'] = 'Fortare bloc radacina <p>';
$lang['forcedrootblockhelp'] = 'Forteaza ca, continutul returnat sa fie incadrat cel putin intr-un tag <p>';
$lang['filepickerstyle'] = 'Stil selector fisiere';
$lang['filepickersize'] = 'Dimensiune selector fisiere';
$lang['allowuploadtext'] = 'Se permite uploadul si crearea de foldere in selectorul de fisiere';
$lang['allowscalingtext'] = 'Se permite redimnesionarea on-the-fly a imaginilor uploadate';
$lang['scalingdimensionstext'] = 'Dimensiuni implicite';
$lang['resizeto'] = 'Redimensionare la:';
$lang['makethumbnail'] = 'Creare miniatura la uploadul imaginilor';
$lang['useadvancedprofile'] = 'Folosire profil avansat TinyMCE';
$lang['saveprofile'] = 'Salvare profil';
$lang['profilesaved'] = 'Profilul a fost salvat';
$lang['profiles_tab'] = 'Profile';
$lang['advanced_backend_toolbars'] = 'Setari avansate profile backend';
$lang['savestyles'] = 'Salvare stiluri';
$lang['allowadvancedprofile'] = 'Se permite folosirea profilulului avansat in TinyMCE';
$lang['showfilemanagement'] = 'Afisare optiuni management fisiere';
$lang['showfilemanagementhelp'] = 'Se afiseaza optiunile de mannagement fisiere cum ar fi upload, creare folder si stergere fisiere in Selector Fisiere, daca utilizatorul are permisiunile necesare pentru aceste operatiuni.';
$lang['restrictdirs'] = 'Restrict user&#039;s dir access';
$lang['restrictdirshelp'] = 'This will restrict the filemanagement-capabilities of the user to a subdir to &#039;uploads&#039; which have the same name as the user&#039;s login. If the subdir does not exist, it will possibly be created. Please note, this currently only works with the standard dirnames, uploads/images. This may change in the future.';
$lang['deleteconfirmation'] = 'Sunteti sigur ca acest fisier trebuie sters?';
$lang['deletefilesuccess'] = 'a fost sters cu succes';
$lang['deletefilefailed'] = 'nu a putut fi sters';
$lang['deletesubdirfailed'] = 'nu a putut fi sters';
$lang['deletesubdirsuccess'] = 'a fost sters cu succes';
$lang['deletedirconfirmation'] = 'Sunteti sigur ca acest subfolder gol ar trebui sa fie sters?';
$lang['deletedir'] = 'Stergere subfolder gol';
$lang['deletefile'] = 'Stergere fisier';
$lang['cannotreadconfig'] = 'Nu s-a putut citi fisierul tinyconfig.php direct asa ca TinyMCE probabil nu va functiona. Ar trebui sa verificati permisiunile pentru fisier si pentru folderele parinte, care ar trebui sa fie de citire pentru toti si cu permisiuni de scriere pentru proprietar.';
$lang['filenameonly'] = 'Afisare nume fisiere';
$lang['thumbnailsonly'] = 'Afisare miniaturi';
$lang['showthumbnailfilestext'] = 'Afisare fisiere miniaturi in liste';
$lang['filenameandthumbnails'] = 'Afisare si nume fisiere si miniaturi';
$lang['skinstext'] = 'Tema';
$lang['skinvariationtext'] = 'Variatie tema';
$lang['advancedwarning'] = '<strong>Luati nota!<br/>Daca schimbati aceste setari puteti face ca TinyMCE sa nu mai mearga sau codul generat sa fie gresit. Editati numai daca stiti ce faceti! Consultati site-ul TinyMCE inainte de a va juca cu aceste setari.</strong>';
$lang['entityencoding_text'] = 'Encodare entitati';
$lang['rawencoding'] = 'Encodare raw (cea mai rapida, functioneaza in cele mai multe cazuri)';
$lang['namedencoding'] = 'Encodare nume (gen &nbsp;)';
$lang['numericencoding'] = 'Encodare numerica (gen &amp;#160;)';
$lang['show_path_text'] = 'Afisare cale element in josul editorului';
$lang['toolbar_tab'] = 'Bara de unelte';
$lang['toolbar_help'] = 'Aceste optiuni ar trebui sa contina o lista de butoane / nume de controale separate prin virgula care se vor insera in bara de unelte. Caracterul | poate fi folosit in loc de cuvantul &#039;separator&#039;';
$lang['toolbar_text'] = 'Bara de unelte';
$lang['toolbarhelptext'] = 'Clic aici pentru a vedea instructiuni referitoare la bara de unelte in TinyMCE-wiki.';
$lang['editor_width_text'] = 'Latime camp editor';
$lang['editor_height_text'] = 'Inaltime camp editor';
$lang['auto'] = 'Auto ';
$lang['or'] = 'sau';
$lang['allowresizing'] = 'Se permite redimensionarea campului editorului in locul in care se afla';
$lang['resizenone'] = 'Nu se permite redimensionarea';
$lang['resizeboth'] = 'Se permite redimensionarea in ambele directii';
$lang['resizeheight'] = 'Se permite numai redimensionarea inaltimii';
$lang['datetimeformat_text'] = 'Format data/timp';
$lang['timetext'] = 'Timp';
$lang['datetext'] = 'Data';
$lang['datetimeformat_help'] = 'Clic aici pentru a primi ajutor despre cum se formateaza data/timpul';
$lang['extraconfigtext'] = 'Extra configurare';
$lang['extraconfighelp2'] = 'O singura declaratie per linie, virgulele vor fi adaugate inainte si dupa acest continut. Vedeti in TinyMCE-wiki pentru instructiuni.';
$lang['customdropdowntext'] = 'Dropdown custom';
$lang['customdropdownhelp'] = 'Insereaza bucati customizabile de cod/text prin selectia lor dintr-un meniu dropdown. 
Utilizari evidente sunt pentru accces facil la taguri etc. Meniul este inserat in bara de unlete folosind &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Startup activat';
$lang['startenabledhelp'] = 'Debifand aceasta casuta se pornesc editoarele Tiny intr-o stare dezactivata. Ar trebui sa fie folosita impreuna cu butonul de stare.';
$lang['loadcmslinkertext'] = 'Incarcare CMS-linker';
$lang['loadcmslinkerhelp'] = 'Aceasta setare genereaza codul javascript de care este nevoie pentru a permite &#039;cmslinker&#039; sa fie adaugat la bara de unelte.';
$lang['cmslinkerstyletext'] = 'Stil link CMS-linker';
$lang['cmsselflinkstyle'] = 'Stil {cms_selflink}';
$lang['ahrefstyle'] = 'stil-<a href>';
$lang['relativeurlstext'] = 'Generare url-uri relative';
$lang['forcecleanpastetext'] = 'Fortare curatare la lipire (paste)';
$lang['forcecleanpastehelp'] = 'Aceasta setare ar trebui sa fie activate pentru a inlatura codurile ciudate de formatare cand se lipeste din Word etc.';
$lang['bodycss_text'] = 'CSS tag body';
$lang['bodycss_help'] = 'Va fi adaugat la definitia css a elementului body. Hint: Culoarea de fundal poate fi setata folosind &quot;background-color: white&quot;';
$lang['includeonlyscreencss_text'] = 'Include numai CSS screen';
$lang['includeonlyscreencss_help'] = 'Daca se selecteaza aceasta optiune numai stylesheet-urile atasate cu mediatype: screen vor fi incluse in stilurile pe care TinyMCE le gestioneaza.';
$lang['usestaticconfigtext'] = 'Folosire fisier configurare static';
$lang['usestaticconfighelp'] = 'Aceasta setare poate ajuta sa mearga TinyMCE pe sistemele unde hostingul adauga statistici etc. la orice output, stricand fisierul de configurare javascript creat dinamic';
$lang['usestaticconfigwarning'] = 'Atentie! Aveti optiunea de fisier de configurare static activata dar folderul /tmp/ nu are permisiuni de scriere. Acest lucru va impiedica modulul sa salveze fisierul static de configurare si sunt sanse foarte mari ca TinyMCE sa NU fie operational.';
$lang['ignoremodifyfilestext'] = 'Ignora &#039;Modifica Fisierul&#039; permisiune pentru FilePicker';
$lang['ignoremodifyfileshelp'] = 'Atentie! Aceasta permite o anumita operatiune fisier-modifica  chiar daca permisiunea &#039;Mofica Fisier&#039; nu este setata pentru grupul de utilizatori curent. Acesta poate fi efectiv folosit impreuna cu optiunea pentru restrictionarea  accesului a directorului untilazator';
$lang['showtogglebutton_text'] = 'Afisare checkbox pentru pornire/oprire wysiwyg';
$lang['togglewysiwyg'] = 'Pornire/oprire WYSIWYG';
$lang['styles_tab'] = 'Stiluri CSS';
$lang['styles_help'] = ' Daca lasati campul gol, TinyMCE va parsa stilesheet-urile CSS si va lista clasele de stiluri pe care le contin. 
  Daca doriti ca numai unele stiluri sa fie afisate utilizatorului, specificati-le in forma &quot;CustomName1=style1; CustomName2=style2&quot;, 
  &quot;style1&quot; fiind o clasa din stylesheet si nu puneti . (punctul) folosit in mod normal pentru selectorii de clase pentru exista deja in CSS, va arata asa <span class=&quot;style1&quot;>text</span>, in primul camp de mai jos. 
';
$lang['css_styles_text'] = 'Stiluri';
$lang['accessdenied'] = 'Acces Interzis. Verificati permisiunile.';
$lang['error'] = 'Eroare!';
$lang['submit'] = 'Trimitere';
$lang['update'] = 'Actualizare';
$lang['savesettings'] = 'Salvare setari';
$lang['settings'] = 'Setari';
$lang['settingssaved'] = 'Setarile au fost salvate';
$lang['saveadvanced'] = 'Salvare setari avansate';
$lang['advancedsaved'] = 'Setarile avansate au fost salvate';
$lang['toolbarsaved'] = 'Bara de unelte a fost salvata';
$lang['stylessaved'] = 'Stilurile au fost salvate';
$lang['testareatext'] = '<p>Arie de test, nici un fel de continut nu va fi stricat daca va jucati aici...</p>';
$lang['reset'] = 'Resetare la setarile implicite';
$lang['resetall'] = 'Resetati toate setarile la valorile implicite';
$lang['confirmreset'] = 'Sunteti sigur ca doriti sa resetati aceste setari la valorile lor implicite?';
$lang['confirmresetall'] = 'Sunteti sigur ca doriti sa resetati TOATE setarile la valorile implicite?';
$lang['settingsreset'] = 'Aceste setari au fost resetate la valorile implicite';
$lang['allsettingsreset'] = 'Toate setarile au fost resetate la valorile implicite';
$lang['upgraded'] = 'a fost actualizat la versiunea %s';
$lang['customdropdown'] = 'Meniu dropdown custom';
$lang['cmsmslinker'] = 'Inserare link catre pagina cmsms';
$lang['backend_toolbars'] = 'Setari profil arie administrare';
$lang['frontend_toolbars'] = 'Setarri profil frontend';
$lang['plugins_tab'] = 'Plugin-uri';
$lang['plugins_help'] = 'Alegeti plugin-urile pe care doriti sa le activati. Documentatia poate fi gasita <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">aici</a>';
$lang['plugins_text'] = 'Plugin-uri';
$lang['saveplugins'] = 'Salvare plugin-uri';
$lang['plugins_module'] = 'Plugin-uri Modul';
$lang['plugins_common'] = 'Plugin-uri Comune';
$lang['module'] = 'Modul';
$lang['description'] = 'Descriere';
$lang['plugin'] = 'Plugin ';
$lang['youareintext'] = 'Sunteti la';
$lang['loadstylesheettext'] = 'Incarcare stylesheet pentru continut (recomandat)';
$lang['extrastylestext'] = 'Adaugiri la stylesheet';
$lang['extrastyleshelp'] = 'CSS-ul introdus aici va fi adaugat la stylesheet-ul citit de TinyMCE dupa ce primeste stilurile CMSms';
$lang['uploadnewfile'] = 'Fisier nou';
$lang['uploadfile'] = 'Upload ';
$lang['createnewdir'] = 'Folder nou';
$lang['createdir'] = 'Creare';
$lang['nodirname'] = 'Nu a fost dat un nume de folder';
$lang['direxists'] = 'Numele de folder exista deja';
$lang['newdircreated'] = 'Folderul nou a fost creat';
$lang['newdirfailed'] = 'O eroare a aparut la creare folder';
$lang['nofile'] = 'Nici un fisier nu a fost uploadat';
$lang['filetoobig'] = 'Fisierul uploadat este prea mare';
$lang['containsillegalchars'] = 'Numele fisierului contine unul sau mai multe caractere ilegale (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['uploadfailed'] = 'Eroare la mutare fisier uploadat la locul lui';
$lang['fileuploaded'] = 'Fisier uploadat cu succes';
$lang['filepickertitle'] = 'Selectie fisier CMSMadeSimple';
$lang['success'] = 'Succes';
$lang['fileoperations'] = 'Operatiuni fisiere';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Dimensiune';
$lang['dimensions'] = 'LxH ';
$lang['advanced_tab'] = 'Avansat';
$lang['help'] = '	<h3>Ce face acesta?</h3>
	<p>Permite folosirea TinyMCE ca editor WYSIWYG.</p>
	<h3>Cum se foloseste?</h3>
	<p>Instalati-l, apoi mergeti la Preferinte utilizator si setati TinyMCE ca editor wysiwyg preferat.</p>
	<h3>Probleme</h3>
	unii utilizatori au probleme cu Tiny la modu ca nu se afiseaza dupa instalare sau actualizare. Aici este un checklist de lucruri pe care le puteti incerca inainte de a cere ajutor mai departe.
	<br/>
	<ul>
	<li>1. Va rugam, VA RUGAM, incercati sa re-uploadati folderul modules/TinyMCE pe server. Ati fi uimiti sa aflati de cate ori acest lucru a salvat situatia.</li>
	<li>2. Incercati sa activati optiunea de fisier configurare static. Notati ca acest lucru cere ca folderul /tmp/ sa aiba permisiuni de scriere pentru webserver</li>
	<li>3. Daca actualizati, incercati sa resetati toate setarile. Nu e frumos daca ati facut o multime de modificari, stim, dar o multime de lucruri se pot schimba de la versiune la versiune.</li>
	</ul>
	<br/>
		
';
$lang['utma'] = '156861353.1477009656.1272913798.1272913798.1274603745.2';
$lang['utmz'] = '156861353.1274603746.2.3.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cms ms';
$lang['qca'] = 'P0-1739349973-1272913798681';
$lang['utmb'] = '156861353.2.10.1274603745';
$lang['utmc'] = '156861353';
?>
